#! /bin/bash

xmllibfile="$( cd -P "$( dirname "$0" )" && pwd )/xmllib.bash"
if [[ "$?" != "0" ]]; then
  echo "Error 1..."
  exit 3
fi
if [[ -f "$xmllibfile" ]]; then
  source "$xmllibfile"
  if [[ "$?" != "0" ]]; then
    echo "Error 2..."
    exit 3
  fi
else
  echo "Error: '$xmllibfile' missing..."
  exit 3
fi

VPIF_XML_FILE=''
VPIF_FILTER_NODE=''
VPIF_FILTER_NODE_NUMBER=''

while getopts "hf:s:n:a:c:x:F:N:TAVE:" opt; do
  case $opt in
    f)
     VPIF_XML_FILE="$OPTARG"
     ;;
    s)
     XML_RD_SET_SEPARATOR="$OPTARG"
     ;;
    n)
     XML_RD_SET_NODE_SEPARATOR="$OPTARG"
     ;;
    a)
     XML_RD_SET_ATTR_SEPARATOR="$OPTARG"
     ;;
    c)
     XML_RD_SET_COMMENT="$OPTARG"
     ;;
    x)
     XML_RD_SET_ROOT="$OPTARG"
     ;;
    F)
     VPIF_FILTER_NODE="$OPTARG"
     ;;
    N)
     VPIF_FILTER_NODE_NUMBER=$((${OPTARG}+0))
     ;;
    T)
     XML_TO_PLAIN_PRINT_TAGS=0
     ;;
    A)
     XML_TO_PLAIN_PRINT_ATTR=0
     ;;
    V)
     XML_READ_VALUE_ONLY=1
     ;;
    E)
     XML_RD_ATTR_FILTER="$OPTARG"
     ;;
    h)
     echo 'Bash simple parse xml file'
     echo ' By Igor Mega, License: BSD 3-Clause, version: 0.11'
     echo ' --------------------------------------------------'
     echo ' -f <xml file>      - file name, reguired'
     echo " -F <filter>        - filter node name full path lead by 'lead-text.' (-x)"
     echo '                      use '=' as last character for the node only.'
     echo " -N <number>        - read/print only <number> occurence "
     echo "                      on found the processing/reading is stoped"
     echo '                      1 = 1st occurence, 2 = 2nd occurence...'
     echo '                      -F should be corect path' 
     echo ' -T                 - NO print tags'
     echo ' -A                 - NO print attributes'
     echo ' -V                 - print value only'
     echo ' -E                 - atribute name filter'
     echo ' Formatting:'
     echo "   -s <key-value-sep> - key-value output separator, default: '${XML_RD_SET_SEPARATOR}'"
     echo "   -n <node-sep>      - node output separator, default: '${XML_RD_SET_NODE_SEPARATOR}'"
     echo "   -a <attribute-sep> - attribute output separator, default: '${XML_RD_SET_ATTR_SEPARATOR}'"
     echo "   -c <comment-sep>   - comment output separator, default: '${XML_RD_SET_COMMENT}'"
     echo "   -x <lead-text>     - each row prefix, default: '${XML_RD_SET_ROOT}'"
     exit 0
     ;;
  \?)
     echo "Invalid option: -$OPTARG" >&2
     exit 1
     ;;
   :)
     echo "Option -$OPTARG requires an argument." >&2
     exit 1
     ;;
  esac
done

if [[ ! -f "${VPIF_XML_FILE}" ]]; then
  echo "error: file '${VPIF_XML_FILE}' doesn't exist"
  exit 3
fi


#1st arg input xml file
#2st filter entity name (optional)
#3nd filter entitty order number 1st occurence = 1, 2ns occurence = 2 ...
xml_to_plain "${VPIF_XML_FILE}" "$VPIF_FILTER_NODE" "$VPIF_FILTER_NODE_NUMBER"
#return zero on succes
